@@ -42,8 +42,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 // Version of this library:
 #define OSL_LIBRARY_VERSION_MAJOR 1
-#define OSL_LIBRARY_VERSION_MINOR 5
-#define OSL_LIBRARY_VERSION_PATCH 12
+#define OSL_LIBRARY_VERSION_MINOR 7
+#define OSL_LIBRARY_VERSION_PATCH 1
 #define OSL_LIBRARY_VERSION_RELEASE_TYPE 
 
 #define OSL_LIBRARY_VERSION_CODE (10000 * OSL_LIBRARY_VERSION_MAJOR + \
@@ -87,5 +87,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define OSL_NAMESPACE_EXIT };
 #endif
 
+/// OSL_BUILD_CPP11 will be 1 if this OSL was built using C++11
+#define OSL_BUILD_CPP11 1
+/// OSL_BUILD_USELIBPLUSPLUS will be 1 if this OSL was built using libc++
+#define OSL_BUILD_LIBCPLUSPLUS 0
 
 #endif /* OSLVERSION_H */
